@@ -1,29 +1,28 @@
-import contextlib
+import ast
 import inspect
-from asyncio import Future, Queue, Task, get_event_loop
-from collections.abc import AsyncGenerator
 from copy import deepcopy
-from typing import Any, ClassVar, cast
+from typing import Any, ClassVar, Self, cast
 
+import anyio
+import anyio.abc
 import nonebot
 from nonebot.adapters import Bot, Event, Message
 from nonebot.internal.matcher import current_bot, current_event
 from nonebot.utils import escape_tag
 from nonebot_plugin_alconna.uniseg import Image, UniMessage
 from nonebot_plugin_session import Session, SessionIdType, extract_session
-from typing_extensions import Self
 
+from .exception import BotEventMismatch, SessionNotInitialized
 from .interface import API, Buffer, default_context, get_api_class
 from .typings import T_Context, T_Executor
 
 logger = nonebot.logger.opt(colors=True)
 
-EXECUTOR_INDENT = " " * 8
 EXECUTOR_FUNCTION = """\
-last_exc, __exception__ = __exception__,  (None, None)
+last_exc, __exception__ = __exception__, (None, None)
 async def __executor__():
     try:
-        {CODE}
+        ...
     except BaseException as e:
         global __exception__
         __exception__ = (e, __import__("traceback").format_exc())
@@ -41,30 +40,27 @@ class Context:
 
     uin: str
     ctx: T_Context
-    locked: bool
-    waitlist: Queue[Future[None]]
-    task: Task[Any] | None
+    lock: anyio.Lock
+    cancel_scope: anyio.CancelScope | None = None
 
     def __init__(self, uin: str) -> None:
         self.uin = uin
         self.ctx = deepcopy(default_context)
-        self.locked = False
-        self.waitlist = Queue()
-        self.task = None
+        self.lock = anyio.Lock()
 
     @classmethod
     def _session2uin(cls, session: Session | Event | str) -> str:
         if isinstance(session, Event):
             if current_event.get() is not session:
-                raise RuntimeError("event mismatch")
+                raise BotEventMismatch
             key = (session.get_user_id(), current_bot.get().type)
             if key not in cls.__ua2session:
-                raise RuntimeError(f"session {key!r} not initialized")
+                raise SessionNotInitialized(key=key)
             session = cls.__ua2session[key]
         elif isinstance(session, str):
             key = (session, current_bot.get().type)
             if key not in cls.__ua2session:
-                raise RuntimeError(f"session {key!r} not initialized")
+                raise SessionNotInitialized(key=key)
             session = cls.__ua2session[key]
 
         key = (session.id1 or "", session.bot_type)
@@ -82,39 +78,21 @@ class Context:
 
         return cls.__contexts[uin]
 
-    @contextlib.asynccontextmanager
-    async def lock(self) -> AsyncGenerator[None, None]:
-        fut: Future[None]
-
-        if self.locked:
-            fut = get_event_loop().create_future()
-            await self.waitlist.put(fut)
-            await fut
-        self.locked = True
-
-        try:
-            yield
-        finally:
-            if not self.waitlist.empty():
-                fut = await self.waitlist.get()
-                fut.set_result(None)
-            self.locked = False
-            self.task = None
-
     def _solve_code(self, raw_code: str, api: API) -> T_Executor:
-        assert self.locked, "`Context._solve_code` called without lock"
+        assert self.lock.locked(), "`Context._solve_code` called without lock"
 
-        # 预处理代码
-        lines: list[str] = [
-            f"global {', '.join(self.ctx.keys())}",
-            *raw_code.split("\n"),
+        parsed = ast.parse(EXECUTOR_FUNCTION, mode="exec")
+        func_def = cast(ast.AsyncFunctionDef, parsed.body[1])
+        cast(ast.Try, func_def.body[0]).body[:] = [
+            ast.Global(names=list(self.ctx)),
+            *ast.parse(raw_code, mode="exec").body,
         ]
-        solved = EXECUTOR_FUNCTION.replace("{CODE}", f"\n{EXECUTOR_INDENT}".join(lines))
+        solved = ast.unparse(parsed)
         code = compile(solved, f"<executor_{self.uin}>", "exec")
 
         # 包装为异步函数
         exec(code, self.ctx, self.ctx)  # noqa: S102
-        executor = self.ctx.pop("__executor__")
+        executor = self.ctx.pop(func_def.name)
 
         if inspect.isasyncgenfunction(executor):
             _executor = executor
@@ -140,13 +118,15 @@ class Context:
         colored_uin = f"<y>{escape_tag(uin)}</y>"
 
         # 执行代码时加锁，避免出现多段代码分别读写变量
-        async with self.lock(), api_class(bot, event, session, self.ctx) as api:
+        async with self.lock, api_class(bot, event, session, self.ctx) as api:
             executor = self._solve_code(code, api)
             escaped = escape_tag(repr(executor))
             logger.debug(f"为用户 {colored_uin} 创建 executor: {escaped}")
 
-            self.task = get_event_loop().create_task(executor())
-            result, self.task = await self.task, None
+            result = None
+            with anyio.CancelScope() as self.cancel_scope:
+                result = await executor()
+            self.cancel_scope = None
 
             if buf := Buffer.get(uin).read().rstrip("\n"):
                 logger.debug(f"用户 {colored_uin} 清空缓冲:")
@@ -163,9 +143,10 @@ class Context:
             raise cast(Exception, exc)
 
     def cancel(self) -> bool:
-        if self.task is None:
+        if self.cancel_scope is None:
             return False
-        return self.task.cancel()
+        self.cancel_scope.cancel()
+        return True
 
     def set_value(self, varname: str, value: Any) -> None:
         if value is not None:
