@@ -1,35 +1,31 @@
-import asyncio
 import contextlib
 import functools
-import uuid
+import re
 from base64 import b64encode
-from collections.abc import Callable
-from datetime import timedelta
+from collections.abc import Awaitable, Callable
 from io import BytesIO
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Protocol, cast
+from typing import TYPE_CHECKING, Any, Protocol, cast, overload, override
 
 import nonebot
-from nonebot import on_fullmatch, on_message
 from nonebot.adapters import Event
-from nonebot.adapters.onebot.v11.message import Message
 from nonebot.utils import escape_tag
-from typing_extensions import override
 
-from ...constant import INTERFACE_METHOD_DESCRIPTION
-from ...typings import T_ForwardMsg, T_Message, UserStr
+from ...exception import APICallFailed as BaseAPICallFailed
+from ...exception import ParamMismatch, ParamMissing
+from ...typings import T_ForwardMsg, UserStr
 from ..api import API as BaseAPI
 from ..api import register_api
+from ..decorators import Overload, debug_log, export, strict
 from ..group import Group as BaseGroup
-from ..help_doc import FuncDescription, descript
+from ..help_doc import descript
 from ..user import User as BaseUser
-from ..utils import Result, as_msg, debug_log, export, is_export_method, strict
-from ._send_ark import SendArk
+from ..utils import Result, as_msg
 
 if TYPE_CHECKING:
 
     class _ApiCall(Protocol):
-        async def __call__(self, **kwargs: Any) -> Any: ...
+        def __call__(self, **kwargs: Any) -> Awaitable[Result]: ...
 
 
 def file2str(file: str | bytes | BytesIO | Path) -> str:
@@ -83,97 +79,52 @@ with contextlib.suppress(ImportError):
         Message,
         MessageEvent,
         MessageSegment,
-        PrivateMessageEvent,
     )
 
+    class APICallFailed(BaseAPICallFailed, ActionFailed): ...
+
     logger = nonebot.logger.opt(colors=True)
 
-    async def create_ark_card(api: "API", ark: "MessageArk") -> MessageSegment:
-        raise NotImplementedError
+    class User(BaseUser["API"]):
+        @descript(
+            description="向用户发送私聊合并转发消息",
+            parameters=dict(msgs="需要发送的消息列表"),
+        )
+        @debug_log
+        @strict
+        async def send_fwd(self, msgs: T_ForwardMsg) -> Result:
+            return await self.api.send_prv_fwd(self.uid, msgs)
 
-    with contextlib.suppress(ImportError, RuntimeError):
-        from nonebot import get_plugin_config
-        from nonebot.adapters.qq import Bot as QQBot
-        from nonebot.adapters.qq import C2CMessageCreateEvent
-        from nonebot.adapters.qq import MessageSegment as QQMS  # noqa: N814
-        from nonebot.adapters.qq.models import MessageArk
-        from pydantic import BaseModel
-
-        class Config(BaseModel):
-            class ExeCodeConfig(BaseModel):
-                qbot_id: int = 0
-                qbot_timeout: float = 30.0
-
-            exe_code: ExeCodeConfig = ExeCodeConfig()
-
-        _conf = get_plugin_config(Config).exe_code
-        if not _conf.qbot_id:  # pragma: no cover
-            logger.warning("官方机器人QQ账号未配置，ark卡片将不可用")
-            raise RuntimeError
-
-        async def create_ark_card(
-            api: "API",
-            ark: MessageArk,
-        ) -> MessageSegment:
-            loop = asyncio.get_running_loop()
-            future: asyncio.Future[str] = loop.create_future()
-
-            key = f"$ARK-{uuid.uuid4()}$"
-            logger.debug(f"生成 ark key: {key}")
-
-            async def handle_qq(bot: QQBot, event: C2CMessageCreateEvent) -> None:
-                logger.debug("QQ Adapter 收到 ark key")
-                try:
-                    await bot.send(event, QQMS.ark(ark))
-                    logger.debug("QQ Adapter 已发送 ark 消息成功")
-                except Exception as err:
-                    logger.debug(f"QQ Adapter 发送 ark 消息失败: {err!r}")
-                    if not future.done():
-                        future.set_exception(err)
-
-            def rule(event: PrivateMessageEvent) -> bool:
-                return event.user_id == _conf.qbot_id and len(event.message) == 1
-
-            async def handle_ob(event: PrivateMessageEvent) -> None:
-                seg = event.message.include("json")[0]
-                logger.debug("OneBot V11 Adapter 收到 ark 卡片")
-                card_json = seg.data["data"]
-                if not future.done():
-                    future.set_result(card_json)
-                    logger.debug(f"OneBot V11 Adapter 设置 future 结果: {card_json}")
-
-            expire = timedelta(seconds=_conf.qbot_timeout)
-            matchers = {
-                on_fullmatch(key, handlers=[handle_qq], temp=True, expire_time=expire),
-                on_message(rule, handlers=[handle_ob], temp=True, expire_time=expire),
-            }
-
-            def cleanup() -> None:  # pragma: no cover
-                for matcher in matchers:
-                    with contextlib.suppress(ValueError):
-                        matcher.destroy()
-
-                if not future.done():
-                    future.set_exception(TimeoutError("卡片获取超时"))
-
-            await api.send_prv(_conf.qbot_id, key)
-            loop.call_later(_conf.qbot_timeout, cleanup)
-            card_json = await future
-            logger.debug("API 调用结束, 获得 card_json")
-            return MessageSegment.json(card_json)
+    class Group(BaseGroup["API"]):
+        @descript(
+            description="向群聊发送合并转发消息",
+            parameters=dict(msgs="需要发送的消息列表"),
+        )
+        @debug_log
+        @strict
+        async def send_fwd(self, msgs: T_ForwardMsg) -> Result:
+            return await self.api.send_grp_fwd(self.uid, msgs)
 
     @register_api(Adapter)
-    class API(SendArk, BaseAPI[Bot, MessageEvent]):
-        @property
-        @override
-        def mid(self) -> int:
-            return self.event.message_id
+    class API(BaseAPI[Bot, MessageEvent]):
+        __slots__ = ()
 
         @classmethod
         @override
         def _validate(cls, bot: Bot, event: Event) -> bool:
             return isinstance(bot, Bot) and isinstance(event, MessageEvent)
 
+        @descript(
+            description="获取当前平台类型",
+            parameters=None,
+            result="当前平台类型",
+        )
+        @debug_log
+        @override
+        async def get_platform(self) -> str:
+            data = await self.bot.get_version_info()
+            return f"[{self.bot.type}] {data['app_name']} {data['app_version']}"
+
         @descript(
             description="调用 OneBot V11 接口",
             parameters=dict(
@@ -195,13 +146,16 @@ with contextlib.suppress(ImportError):
         ) -> Result:
             res: dict[str, Any] | list[Any] | None = None
             try:
-                res = await self.bot.call_api(api, **data)
+                res = await self.bot.call_api(
+                    api,
+                    **{k: v for k, v in data.items() if v is not None},
+                )
             except ActionFailed as e:
                 res = {"error": e}
             except BaseException as e:
                 res = {"error": e}
                 msg = (
-                    f"用户(<c>{escape_tag(self.qid)}<c>) "
+                    f"用户(<c>{escape_tag(self.uid)}<c>) "
                     f"调用 api <y>{escape_tag(api)}</y> 时发生错误: "
                     f"<r>{escape_tag(repr(e))}</r>"
                 )
@@ -225,18 +179,18 @@ with contextlib.suppress(ImportError):
             return functools.partial(self.call_api, name)
 
         @descript(
-            description="向QQ号为qid的用户发送合并转发消息",
+            description="向用户ID为uid的用户发送合并转发消息",
             parameters=dict(
-                qid="需要发送消息的QQ号",
+                uid="需要发送消息的用户ID",
                 msgs="发送的消息列表",
             ),
         )
         @debug_log
         @strict
-        async def send_prv_fwd(self, qid: int | str, msgs: T_ForwardMsg) -> Result:
+        async def send_prv_fwd(self, uid: int | str, msgs: T_ForwardMsg) -> Result:
             return await self.call_api(
                 "send_private_forward_msg",
-                user_id=int(qid),
+                user_id=int(uid),
                 messages=await convert_forward(msgs),
             )
 
@@ -256,50 +210,50 @@ with contextlib.suppress(ImportError):
                 messages=await convert_forward(msgs),
             )
 
-        @export
         @descript(
             description="向当前会话发送合并转发消息",
             parameters=dict(msgs="发送的消息列表"),
         )
+        @export
         @debug_log
         @strict
         async def send_fwd(self, msgs: T_ForwardMsg) -> Result:
             if not self.is_group():
-                return await self.send_prv_fwd(self.qid, msgs)
-            if self.gid is not None:
-                return await self.send_grp_fwd(self.gid, msgs)
-            raise ValueError("获取消息上下文失败")
+                return await self.send_prv_fwd(self.uid, msgs)
+            assert self.gid is not None, "获取上下文失败"
+            return await self.send_grp_fwd(self.gid, msgs)
 
-        @export
-        @override
-        @descript(
-            description="向当前会话发送API说明",
-            parameters=dict(method="需要获取帮助的函数，留空则为合并转发的完整文档"),
-        )
-        @debug_log
-        @strict
-        async def help(self, method: Callable | None = None) -> None:
-            if method is not None:
-                desc: FuncDescription = getattr(method, INTERFACE_METHOD_DESCRIPTION)
-                text = desc.format(method)
-                if not is_export_method(method):
-                    text = f"{self.__inst_name__}.{text}"
-                await self.feedback(text)
-                return
+        @overload
+        async def help(self, method: Callable[..., Any]) -> None:
+            await super().help(method)
 
+        @overload
+        async def help(self) -> None:
             content, description = self.get_all_description()
-            msgs: list[T_Message] = [
+            msgs = [
                 "   ===== API说明 =====   ",
                 " - API说明文档 - 目录 - \n" + "\n".join(content),
                 *description,
             ]
             await self.send_fwd(msgs)
 
+        @Overload
+        @descript(
+            description="向当前会话发送API说明",
+            parameters=dict(method="需要获取帮助的函数，留空则为合并转发的完整文档"),
+        )
         @export
+        @debug_log
+        @override
+        async def help(  # pyright: ignore[reportIncompatibleVariableOverride]
+            self, method: Callable[..., Any] | None = None
+        ) -> None: ...
+
         @descript(
             description="撤回指定消息",
             parameters=dict(msg_id="需要撤回的消息ID，可通过Result/getmid获取"),
         )
+        @export
         @debug_log
         @strict
         async def recall(self, msg_id: int) -> Result:
@@ -310,12 +264,12 @@ with contextlib.suppress(ImportError):
                 raise_text="撤回消息失败",
             )
 
-        @export
         @descript(
             description="通过消息ID获取指定消息",
             parameters=dict(msg_id="需要获取的消息ID，可通过getmid获取"),
             result="获取到的消息",
         )
+        @export
         @debug_log
         @strict
         async def get_msg(self, msg_id: int) -> Message:
@@ -327,12 +281,12 @@ with contextlib.suppress(ImportError):
             )
             return Message(res["raw_message"])
 
-        @export
         @descript(
             description="通过合并转发ID获取合并转发消息",
             parameters=dict(msg_id="需要获取的合并转发ID，可通过getcqcode获取"),
             result="获取到的合并转发消息列表",
         )
+        @export
         @debug_log
         @strict
         async def get_fwd(self, msg_id: int) -> list[Message]:
@@ -360,7 +314,7 @@ with contextlib.suppress(ImportError):
                 url = Context.get_context(self.session).ctx.get("gurl")
 
             if not url:
-                raise ValueError("无效 url")
+                raise ParamMissing("无效 url")
 
             logger.debug(f"[NapCat] 创建图片外显: <y>{summary}</y>, <c>{url}</c>")
             seg = MessageSegment.image(url)
@@ -371,7 +325,7 @@ with contextlib.suppress(ImportError):
             description="设置群名片",
             parameters=dict(
                 card="新的群名片",
-                qid="被设置者QQ号, 默认为当前用户",
+                uid="被设置者用户ID, 默认为当前用户",
                 gid="所在群号, 默认为当前群聊, 私聊时必填",
             ),
         )
@@ -380,15 +334,15 @@ with contextlib.suppress(ImportError):
         async def set_card(
             self,
             card: str,
-            qid: str | int | None = None,
+            uid: str | int | None = None,
             gid: str | int | None = None,
         ) -> None:
             if gid is None and self.gid is None:
-                raise ValueError("未指定群号")
+                raise ParamMissing("未指定群号")
             await self.call_api(
                 "set_group_card",
                 group_id=int(gid or self.gid or 0),
-                user_id=int(qid or self.qid),
+                user_id=int(uid or self.uid),
                 card=str(card),
             )
 
@@ -396,7 +350,7 @@ with contextlib.suppress(ImportError):
             description="设置群禁言",
             parameters=dict(
                 duration="禁言时间, 单位秒, 填0为解除禁言",
-                qid="被禁言者QQ号",
+                uid="被禁言者用户ID",
                 gid="所在群号, 默认为当前群聊, 私聊时必填",
             ),
         )
@@ -404,16 +358,16 @@ with contextlib.suppress(ImportError):
         @strict
         async def set_mute(
             self,
-            duration: float,
-            qid: str | int,
+            duration: int | float,  # noqa: PYI041
+            uid: str | int,
             gid: str | int | None = None,
         ) -> None:
             if gid is None and self.gid is None:
-                raise ValueError("未指定群号")
+                raise ParamMissing("未指定群号")
             await self.call_api(
                 "set_group_ban",
                 group_id=int(gid or self.gid or 0),
-                user_id=int(qid),
+                user_id=int(uid),
                 duration=float(duration),
             )
 
@@ -421,19 +375,19 @@ with contextlib.suppress(ImportError):
             description="资料卡点赞，需要机器人好友",
             parameters=dict(
                 times="点赞次数，非vip机器人每天上限10次",
-                qid="点赞QQ号, 默认为当前用户",
+                uid="点赞用户ID, 默认为当前用户",
             ),
         )
         @debug_log
         @strict
-        async def send_like(self, times: int, qid: str | int | None = None) -> None:
-            await self.call_api("send_like", user_id=int(qid or self.qid), times=times)
+        async def send_like(self, times: int, uid: str | int | None = None) -> None:
+            await self.call_api("send_like", user_id=int(uid or self.uid), times=times)
 
         @descript(
             description="[NapCat/LLOneBot/Lagrange] 群聊消息回应",
             parameters=dict(
                 emoji_id="回应的表情ID",
-                message_id="需要回应的消息ID，可通过getmid获取",
+                message_id="需要回应的消息ID，可通过getmid获取，默认为当前回复消息/当前消息",
                 gid="[Lagrange] 指定群聊ID，默认为当前群聊",
             ),
         )
@@ -442,32 +396,38 @@ with contextlib.suppress(ImportError):
         async def set_reaction(
             self,
             emoji_id: str | int,
-            message_id: str | int,
+            message_id: str | int | None = None,
             gid: str | int | None = None,
-        ) -> None:
-            with contextlib.suppress(ActionFailed):
+        ) -> Result:
+            if message_id is None:
+                message_id = self.event.message_id
+                if self.event.reply is not None:
+                    message_id = self.event.reply.message_id
+
+            platform = (await self.get_platform()).lower()
+            if "napcat" in platform or "llonebot" in platform:
                 # NapCat/LLOneBot
-                await self.call_api(
+                return await self.call_api(
                     "set_msg_emoji_like",
                     message_id=int(message_id),
                     emoji_id=int(emoji_id),
                     raise_text="调用 NapCat/LLOneBot 接口 set_msg_emoji_like 出错",
                 )
-                return
 
-            if (gid := gid or self.gid) is not None:
-                with contextlib.suppress(ActionFailed):
-                    # Lagrange
-                    await self.call_api(
-                        "set_group_reaction",
-                        group_id=int(gid),
-                        message_id=int(message_id),
-                        code=str(emoji_id),
-                        raise_text="调用 Lagrange 接口 set_group_reaction 出错",
-                    )
-                    return
+            if "lagrange" in platform:
+                if (gid := gid or self.gid) is None:
+                    raise ParamMissing("在 Lagrange 下进行表情回应需要指定群号")
 
-            raise RuntimeError("发送消息回应失败")
+                # Lagrange
+                return await self.call_api(
+                    "set_group_reaction",
+                    group_id=int(gid),
+                    message_id=int(message_id),
+                    code=str(emoji_id),
+                    raise_text="调用 Lagrange 接口 set_group_reaction 出错",
+                )
+
+            raise APICallFailed(f"发送消息回应失败: 未知平台 {platform}")
 
         @descript(
             description="发送群文件",
@@ -475,6 +435,7 @@ with contextlib.suppress(ImportError):
                 file="需要发送的文件，可以是url/base64/bytes/Path",
                 name="上传的文件名",
                 gid="目标群号，默认为当前群聊，私聊时必填",
+                timeout="上传文件超时时长，单位秒",
             ),
         )
         @debug_log
@@ -484,13 +445,14 @@ with contextlib.suppress(ImportError):
             file: str | bytes | BytesIO | Path,
             name: str,
             gid: str | int | None = None,
+            timeout: float | None = None,  # noqa: ASYNC109
         ) -> None:
             file = file2str(file)
             gid = gid or self.gid
             if gid is None:
-                raise ValueError("未指定群号")
+                raise ParamMissing("未指定群号")
             if not str(gid).isdigit():
-                raise ValueError(f"群号错误: {gid} 不是数字")
+                raise ParamMismatch(f"群号错误: {gid} 不是数字")
 
             # https://docs.go-cqhttp.org/api/#%E4%B8%8A%E4%BC%A0%E7%BE%A4%E6%96%87%E4%BB%B6
             await self.call_api(
@@ -498,6 +460,7 @@ with contextlib.suppress(ImportError):
                 group_id=int(gid),
                 file=file,
                 name=name,
+                _timeout=timeout,
             )
 
         @descript(
@@ -505,7 +468,8 @@ with contextlib.suppress(ImportError):
             parameters=dict(
                 file="需要发送的文件，可以是url/base64/bytes/Path",
                 name="上传的文件名",
-                qid="目标QQ号，默认为当前用户",
+                uid="目标用户ID，默认为当前用户",
+                timeout="上传文件超时时长，单位秒",
             ),
         )
         @debug_log
@@ -514,19 +478,21 @@ with contextlib.suppress(ImportError):
             self,
             file: str | bytes | BytesIO | Path,
             name: str,
-            qid: str | int | None = None,
+            uid: str | int | None = None,
+            timeout: float | None = None,  # noqa: ASYNC109
         ) -> None:
             file = file2str(file)
-            qid = qid or self.qid
-            if not str(qid).isdigit():
-                raise ValueError(f"QQ号错误: {qid} 不是数字")
+            uid = uid or self.uid
+            if not str(uid).isdigit():
+                raise ParamMismatch(f"用户ID错误: {uid} 不是数字")
 
             # https://docs.go-cqhttp.org/api/#%E4%B8%8A%E4%BC%A0%E7%A7%81%E8%81%8A%E6%96%87%E4%BB%B6
             await self.call_api(
                 "upload_private_file",
-                user_id=int(qid),
+                user_id=int(uid),
                 file=file,
                 name=name,
+                _timeout=timeout,
             )
 
         @descript(
@@ -534,6 +500,7 @@ with contextlib.suppress(ImportError):
             parameters=dict(
                 file="需要发送的文件，可以是url/base64/bytes/Path",
                 name="上传的文件名",
+                timeout="上传文件超时时长，单位秒",
             ),
         )
         @debug_log
@@ -542,58 +509,103 @@ with contextlib.suppress(ImportError):
             self,
             file: str | bytes | BytesIO | Path,
             name: str,
+            timeout: float | None = None,  # noqa: ASYNC109
         ) -> None:
             if self.is_group():
-                await self.send_group_file(file, name, self.gid)
+                await self.send_group_file(file, name, self.gid, timeout)
             else:
-                await self.send_private_file(file, name, self.qid)
+                await self.send_private_file(file, name, self.uid, timeout)
 
-        @override
-        async def _send_ark(self, ark: "MessageArk") -> Any:
-            card = Message(await create_ark_card(self, ark))
-            return await self.native_send(card)
-
-        @export
         @descript(
             description="获取用户对象",
-            parameters=dict(uid="用户QQ号"),
+            parameters=dict(uid="用户ID"),
             result="User对象",
         )
+        @export
         @strict
-        def user(  # pyright: ignore[reportIncompatibleMethodOverride]
+        def user(  # pyright: ignore[reportIncompatibleVariableOverride]
             self, uid: int | str
-        ) -> "User":
+        ) -> User:
             return User(self, str(uid))
 
-        @export
         @descript(
             description="获取群聊对象",
             parameters=dict(gid="群号"),
             result="Group对象",
         )
+        @export
         @strict
-        def group(  # pyright: ignore[reportIncompatibleMethodOverride]
+        def group(  # pyright: ignore[reportIncompatibleVariableOverride]
             self, gid: int | str
-        ) -> "Group":
+        ) -> Group:
             return Group(self, str(gid))
 
-    class User(BaseUser[API]):
-        @override
         @descript(
-            description="向用户发送私聊合并转发消息",
-            parameters=dict(msgs="需要发送的消息列表"),
+            description="发送 Markdown 消息",
+            parameters=dict(
+                md="Markdown 文本",
+                uid="发送时显示的用户 ID",
+                gid="发送时显示的群组 ID",
+                nick="发送时显示的用户名",
+            ),
         )
+        @export
         @debug_log
         @strict
-        async def send_fwd(self, msgs: T_ForwardMsg) -> Result:
-            return await self.api.send_prv_fwd(self.uid, msgs)
+        async def send_md(
+            self,
+            md: str,
+            uid: int | str | None = None,
+            gid: int | str | None = None,
+            nick: str | None = None,
+        ) -> None:  # pragma: no cover
+            async def send(type_: str, data: dict[str, Any], /) -> Result:
+                node = {
+                    "type": "node",
+                    "data": {
+                        "nickname": nick or "fake",
+                        "user_id": int(uid or self.bot.self_id),
+                        "content": [{"type": type_, "data": data}],
+                    },
+                }
+                return await self.call_api(
+                    "send_group_forward_msg",
+                    group_id=int(gid or self.gid or 10086),
+                    messages=[node],
+                )
+
+            res = await send("markdown", {"content": md})
+            if not isinstance(res.error, ActionFailed):
+                raise APICallFailed("Markdown 消息发送失败: 伪造合并转发失败")
+
+            m = re.search(r"res_id：(.+?)\s失败", res.error.info["message"])
+            if m is None:
+                raise APICallFailed("Markdown 消息发送失败: 无法提取 res_id")
+
+            res = await send("forward", {"id": m.group(1)})
+            if res.error:
+                raise APICallFailed("Markdown 消息发送失败") from res.error
 
-    class Group(BaseGroup[API]):
         @descript(
-            description="向群聊发送合并转发消息",
-            parameters=dict(msgs="需要发送的消息列表"),
+            description="群聊戳一戳",
+            parameters=dict(
+                uid="被戳用户ID",
+                gid="所在群号, 默认为当前群聊",
+            ),
         )
+        @export
         @debug_log
         @strict
-        async def send_fwd(self, msgs: T_ForwardMsg) -> Result:
-            return await self.api.send_grp_fwd(self.uid, msgs)
+        async def group_poke(
+            self,
+            uid: str | int,
+            gid: str | int | None = None,
+        ) -> None:
+            if (gid := gid or self.gid) is None:
+                raise ParamMissing("未指定群号")
+
+            await self.call_api(
+                "group_poke",
+                group_id=int(gid),
+                user_id=int(uid),
+            )
