@@ -1,14 +1,15 @@
-import asyncio
 from collections.abc import Callable
-from typing import Any, ClassVar, Generic, TypeVar
+from typing import Any, ClassVar, Self, override
 
+import anyio
 from nonebot.adapters import Adapter, Bot, Event, Message, MessageSegment
-from nonebot_plugin_alconna.uniseg import Receipt, Target, UniMessage
+from nonebot_plugin_alconna.uniseg import Receipt, Target, UniMessage, reply_fetch
 from nonebot_plugin_session import Session, SessionIdType
 from nonebot_plugin_waiter import prompt as waiter_prompt
-from typing_extensions import Self, override
 
-from ..typings import T_ConstVar, T_Context, T_Message
+from ..exception import BotEventMismatch, NoMethodDescription
+from ..typings import T_ConstVar, T_Context, T_Message, is_message_t
+from .decorators import debug_log, export, strict
 from .group import Group
 from .help_doc import descript, message_alia
 from .interface import Interface
@@ -18,27 +19,20 @@ from .utils import (
     Buffer,
     as_msg,
     as_unimsg,
-    debug_log,
-    export,
     export_message,
     export_superuser,
     get_method_description,
     is_export_method,
-    is_message_t,
     is_super_user,
     send_message,
-    strict,
 )
 
-_A = TypeVar("_A", bound=type["API"])
-_B = TypeVar("_B", bound=Bot)
-_E = TypeVar("_E", bound=Event)
 api_registry: dict[type[Adapter], type["API"]] = {}
 message_alia(Message, MessageSegment)
 
 
-def register_api(adapter: type[Adapter]) -> Callable[[_A], _A]:
-    def decorator(api: _A) -> _A:
+def register_api[A: type["API"]](adapter: type[Adapter]) -> Callable[[A], A]:
+    def decorator(api: A) -> A:
         api_registry[adapter] = api
         adapter_name = adapter.get_name()
         for desc in api.__method_description__.values():
@@ -48,19 +42,19 @@ def register_api(adapter: type[Adapter]) -> Callable[[_A], _A]:
     return decorator
 
 
-class API(Generic[_B, _E], Interface):
+class API[B: Bot, E: Event](Interface):
     __inst_name__: ClassVar[str] = "api"
     __slots__ = ("__bot", "__event", "__session")
 
     def __init__(
         self,
-        bot: _B,
-        event: _E,
+        bot: B,
+        event: E,
         session: Session,
         context: T_Context,
     ) -> None:
         if not self._validate(bot, event):
-            raise RuntimeError("Bot/Event type mismatch")
+            raise BotEventMismatch("Bot/Event type mismatch")
 
         super().__init__(context)
         self.__bot = bot
@@ -68,11 +62,11 @@ class API(Generic[_B, _E], Interface):
         self.__session = session
 
     @property
-    def bot(self) -> _B:
+    def bot(self) -> B:
         return self.__bot
 
     @property
-    def event(self) -> _E:
+    def event(self) -> E:
         return self.__event
 
     @property
@@ -80,7 +74,7 @@ class API(Generic[_B, _E], Interface):
         return self.__session
 
     @property
-    def qid(self) -> str:
+    def uid(self) -> str:
         return self.session.id1 or ""
 
     @property
@@ -96,8 +90,28 @@ class API(Generic[_B, _E], Interface):
         return UniMessage.get_message_id(self.event, self.bot)
 
     @classmethod
-    def _validate(cls, bot: _B, event: _E) -> bool:  # noqa: ARG003
-        return True
+    def _validate(cls, bot: B, event: E) -> bool:
+        return isinstance(bot, Bot) and isinstance(event, Event)
+
+    @descript(
+        description="获取当前平台类型",
+        parameters=None,
+        result="当前平台类型",
+    )
+    @debug_log
+    async def get_platform(self) -> str:
+        return self.bot.type
+
+    @descript(
+        description="获取当前消息的引用消息 ID",
+        parameters=None,
+        result="引用消息的 ID",
+    )
+    @export
+    @debug_log
+    async def reply_id(self) -> str | None:
+        reply = await reply_fetch(self.event, self.bot)
+        return reply and reply.id
 
     @descript(
         description="调用 bot.send 向当前会话发送平台消息",
@@ -114,28 +128,32 @@ class API(Generic[_B, _E], Interface):
         msg: Any,
         **kwds: Any,
     ) -> Any:
-        return await self.bot.send(self.event, await as_msg(msg), **kwds)
+        return await self.bot.send(
+            event=self.event,
+            message=await as_msg(msg),
+            **kwds,
+        )
 
     @descript(
-        description="向QQ号为qid的用户发送私聊消息",
+        description="向用户ID为uid的用户发送私聊消息",
         parameters=dict(
-            qid="需要发送私聊的QQ号",
+            uid="需要发送私聊的用户ID",
             msg="发送的内容",
         ),
     )
     @debug_log
     @strict
-    async def send_prv(self, qid: int | str, msg: T_Message) -> Receipt:
+    async def send_prv(self, uid: int | str, msg: T_Message) -> Receipt:
         return await send_message(
             session=self.session,
-            target=Target.user(str(qid)),
+            target=Target.user(str(uid)),
             message=msg,
         )
 
     @descript(
-        description="向群号为gid的群聊发送消息",
+        description="向群组ID为gid的群组发送消息",
         parameters=dict(
-            gid="需要发送消息的群号",
+            gid="需要发送消息的群组ID",
             msg="发送的内容",
         ),
     )
@@ -150,14 +168,10 @@ class API(Generic[_B, _E], Interface):
 
     @descript(
         description="向当前会话发送消息",
-        parameters=dict(
-            msg="需要发送的消息",
-            fwd="传入的是否为合并转发消息列表",
-        ),
+        parameters=dict(msg="需要发送的消息"),
     )
     @export
     @debug_log
-    @strict
     async def feedback(self, msg: Any) -> Receipt:
         if not is_message_t(msg):
             msg = str(msg)
@@ -226,7 +240,7 @@ class API(Generic[_B, _E], Interface):
     async def input(
         self,
         prompt: T_Message | None = None,
-        timeout: float = 30,
+        timeout: float = 30,  # noqa: ASYNC109
     ) -> UniMessage:
         prompt = (
             await (await as_unimsg(prompt)).export(self.bot)
@@ -247,7 +261,7 @@ class API(Generic[_B, _E], Interface):
     async def help(self, method: Callable[..., Any]) -> None:
         desc = get_method_description(method)
         if desc is None:
-            raise TypeError(f"{method!r} 没有方法描述")
+            raise NoMethodDescription(method=method)
         text = desc.format()
         if not is_export_method(method):
             text = f"{desc.inst_name}.{text}"
@@ -260,8 +274,8 @@ class API(Generic[_B, _E], Interface):
     @export
     @debug_log
     @strict
-    async def sleep(self, seconds: float) -> None:
-        await asyncio.sleep(seconds)
+    async def sleep(self, seconds: int | float) -> None:  # noqa: PYI041
+        await anyio.sleep(seconds)
 
     @descript(
         description="重置环境",
@@ -283,14 +297,15 @@ class API(Generic[_B, _E], Interface):
 
         for k, v in load_const(self.session_id).items():
             self._export(k, v)
-        self._export("qid", self.qid)
+        self._export("uid", self.uid)
+        self._export("qid", self.uid)
         self._export("gid", self.gid)
-        for k, v in export_message(self.bot.adapter).items():
+        for k, v in export_message(self.bot.adapter):
             self._export(k, v)
 
-        if is_super_user(self.bot, self.qid):
-            for k, v in export_superuser().items():
+        if is_super_user(self.bot, self.uid):
+            for k, v in export_superuser():
                 self._export(k, v)
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__name__} user_id={self.qid}>"
+        return f"<{self.__class__.__name__} user_id={self.uid}>"
