@@ -1,139 +1,37 @@
-import asyncio
-import functools
-import inspect
-from collections.abc import Callable, Coroutine
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    ClassVar,
-    Generic,
-    ParamSpec,
-    TypeVar,
-    cast,
-    overload,
-)
+from collections.abc import Awaitable, Callable, Generator
+from typing import TYPE_CHECKING, Any, ClassVar, Self, cast
 
+import anyio
+import anyio.abc
 import nonebot
 from nonebot.adapters import Adapter, Bot, Message, MessageSegment
-from nonebot.utils import is_coroutine_callable
 from nonebot_plugin_alconna.uniseg import Receipt, Segment, Target, UniMessage
 from nonebot_plugin_session import Session
-from typing_extensions import Self, TypeIs
 
-from ..typings import T_API_Result, T_Context, T_Message, generic_check_isinstance
+from ..config import config
+from ..typings import T_API_Result, T_Context, T_Message, is_message_t
+from .decorators import INTERFACE_EXPORT_METHOD, INTERFACE_METHOD_DESCRIPTION, strict
 
 if TYPE_CHECKING:
     from .help_doc import MethodDescription
 
-INTERFACE_EXPORT_METHOD = "__export_method__"
-INTERFACE_METHOD_DESCRIPTION = "__method_description__"
-WRAPPER_ASSIGNMENTS = (
-    *functools.WRAPPER_ASSIGNMENTS,
-    INTERFACE_EXPORT_METHOD,
-    INTERFACE_METHOD_DESCRIPTION,
-)
 
-_P = ParamSpec("_P")
-_R = TypeVar("_R")
-_T = TypeVar("_T")
-
-
-def export(call: Callable[_P, _R]) -> Callable[_P, _R]:
-    """将一个方法标记为导出函数"""
-    setattr(call, INTERFACE_EXPORT_METHOD, True)
-    return call
+def is_export_method(call: Callable[..., Any]) -> bool:
+    """判断一个方法是否为导出函数
+    Args:
+        call (Callable[..., Any]): 待判断的方法
+    Returns:
+        bool: 该方法是否为导出函数
+    """
+    return getattr(call, INTERFACE_EXPORT_METHOD, False)
 
 
 def get_method_description(call: Callable[..., Any]) -> "MethodDescription | None":
-    return getattr(call, INTERFACE_METHOD_DESCRIPTION, None)
-
-
-class Coro(Coroutine[None, None, _T], Generic[_T]): ...
-
-
-@overload
-def debug_log(call: Callable[_P, Coro[_R]]) -> Callable[_P, Coro[_R]]: ...
-@overload
-def debug_log(call: Callable[_P, _R]) -> Callable[_P, _R]: ...
-
-
-def debug_log(
-    call: Callable[_P, Coro[_R]] | Callable[_P, _R],
-) -> Callable[_P, Coro[_R]] | Callable[_P, _R]:
-    if is_coroutine_callable(call):
-
-        async def wrapper(  # pyright: ignore[reportRedeclaration]
-            *args: _P.args, **kwargs: _P.kwargs
-        ) -> _R:
-            nonebot.logger.debug(f"{call.__name__}: args={args!r}, kwargs={kwargs!r}")
-            return await cast(Callable[_P, Coro[_R]], call)(*args, **kwargs)
-
-    else:
-
-        def wrapper(*args: _P.args, **kwargs: _P.kwargs) -> _R:
-            nonebot.logger.debug(f"{call.__name__}: args={args!r}, kwargs={kwargs!r}")
-            return cast(Callable[_P, _R], call)(*args, **kwargs)
-
-    return cast(
-        Callable[_P, Coro[_R]] | Callable[_P, _R],
-        functools.update_wrapper(wrapper, call, assigned=WRAPPER_ASSIGNMENTS),
-    )
-
-
-@overload
-def strict(call: Callable[_P, Coro[_R]]) -> Callable[_P, Coro[_R]]: ...
-@overload
-def strict(call: Callable[_P, _R]) -> Callable[_P, _R]: ...
-
-
-def strict(
-    call: Callable[_P, Coro[_R]] | Callable[_P, _R],
-) -> Callable[_P, Coro[_R]] | Callable[_P, _R]:
-    sig = inspect.signature(call)
-    params = sig.parameters.copy()
-    params.pop("cls", None)
-    params.pop("self", None)
-
-    if any(param.annotation is sig.empty for param in params.values()):
-        raise TypeError(f"Strict callable {call.__name__!r} is not fully typed")
-
-    def check_args(args: tuple, kwargs: dict) -> None:
-        arguments = sig.bind(*args, **kwargs).arguments
-        for name, value in arguments.items():
-            if name in {"cls", "self"}:
-                continue
-            annotation = sig.parameters[name].annotation
-            if not generic_check_isinstance(value, annotation):
-                from .help_doc import format_annotation
-
-                raise TypeError(
-                    f"Invalid argument for param {name!r} of {call.__name__!r}: "
-                    f"expect {format_annotation(annotation)}, "
-                    f"got {format_annotation(type(value))}"
-                )
-
-    if is_coroutine_callable(call):
-
-        async def wrapper(  # pyright: ignore[reportRedeclaration]
-            *args: _P.args, **kwargs: _P.kwargs
-        ) -> _R:
-            check_args(args, kwargs)
-            return await cast(Callable[_P, Coro[_R]], call)(*args, **kwargs)
-
-    else:
-
-        def wrapper(*args: _P.args, **kwargs: _P.kwargs) -> _R:
-            check_args(args, kwargs)
-            return cast(Callable[_P, _R], call)(*args, **kwargs)
-
-    return cast(
-        Callable[_P, Coro[_R]] | Callable[_P, _R],
-        functools.update_wrapper(wrapper, call, assigned=WRAPPER_ASSIGNMENTS),
-    )
-
-
-def is_export_method(call: Callable[..., Any]) -> bool:
-    return getattr(call, INTERFACE_EXPORT_METHOD, False)
+    if (ref := getattr(call, INTERFACE_METHOD_DESCRIPTION, None)) is None:
+        return None
+    if (desc := ref()) is None:
+        raise RuntimeError("Fail to solve weak refrence")  # pragma: no cover
+    return desc
 
 
 def is_super_user(bot: Bot, uin: str) -> bool:
@@ -158,6 +56,9 @@ class Buffer:
         return cls._user_buf[uin]
 
     def write(self, text: str) -> None:
+        if len(self._buffer) + len(text) > config.buffer_size:
+            raise OverflowError("缓冲区溢出")
+
         self._buffer += str(text)
 
     def read(self) -> str:
@@ -191,38 +92,34 @@ class Result:
         return f"<Result data={self._data!r}>"
 
 
-def is_message_t(message: Any) -> TypeIs[T_Message]:
-    return isinstance(message, T_Message)
+async def as_unimsg(message: Any) -> UniMessage[Any]:
+    msg = message
+    if not is_message_t(msg):
+        msg = str(msg)
+    if isinstance(msg, MessageSegment):
+        msg = cast(type[Message], msg.get_message_class())(msg)
+    if isinstance(msg, str):
+        msg = UniMessage.text(msg)
+    elif isinstance(msg, Segment):
+        msg = UniMessage(msg)
+    elif isinstance(msg, Message):
+        msg = await UniMessage.generate(message=msg)
+    return msg
 
 
-async def as_unimsg(message: Any) -> UniMessage:
-    if not is_message_t(message):
-        message = str(message)
-    if isinstance(message, MessageSegment):
-        message = cast(type[Message], message.get_message_class())(message)
-    if isinstance(message, str):
-        message = UniMessage.text(message)
-    if isinstance(message, Segment):
-        message = UniMessage(message)
-    elif isinstance(message, Message):
-        message = await UniMessage.generate(message=message)
-
-    return message
-
-
-def as_unimsg_sync(message: Any) -> UniMessage:
-    if not is_message_t(message):
-        message = str(message)
-    if isinstance(message, MessageSegment):
-        message = cast(type[Message], message.get_message_class())(message)
-    if isinstance(message, str):
-        message = UniMessage.text(message)
-    if isinstance(message, Segment):
-        message = UniMessage(message)
-    elif isinstance(message, Message):
-        message = UniMessage.generate_sync(message=message)
-
-    return message
+def as_unimsg_sync(message: Any) -> UniMessage[Any]:
+    msg = message
+    if not is_message_t(msg):
+        msg = str(msg)
+    if isinstance(msg, MessageSegment):
+        msg = cast(type[Message], msg.get_message_class())(msg)
+    if isinstance(msg, str):
+        msg = UniMessage.text(msg)
+    elif isinstance(msg, Segment):
+        msg = UniMessage(msg)
+    elif isinstance(msg, Message):
+        msg = UniMessage.generate_sync(message=msg)
+    return msg
 
 
 async def as_msg(message: Any) -> Message:
@@ -239,6 +136,51 @@ async def as_msg(message: Any) -> Message:
     return message
 
 
+class GlobalTaskGroup:
+    task_group: anyio.abc.TaskGroup
+
+    @staticmethod
+    @nonebot.get_driver().on_startup
+    async def on_startup() -> None:
+        GlobalTaskGroup.task_group = anyio.create_task_group()
+        await GlobalTaskGroup.task_group.__aenter__()
+
+    @staticmethod
+    @nonebot.get_driver().on_shutdown
+    async def on_shutdown() -> None:
+        GlobalTaskGroup.task_group.cancel_scope.cancel()
+        await GlobalTaskGroup.task_group.__aexit__(None, None, None)
+
+    @classmethod
+    def call_later[**P](
+        cls,
+        delay: float,
+        callback: Callable[P, Awaitable[Any]],
+        *args: P.args,
+        **kwargs: P.kwargs,
+    ) -> Callable[[], None]:
+        scope: anyio.CancelScope | None = None
+
+        @cls.task_group.start_soon
+        async def _() -> None:
+            nonlocal scope
+
+            with anyio.CancelScope() as scope:
+                await anyio.sleep(delay)
+                await callback(*args, **kwargs)
+
+        return lambda: scope and scope.cancel()
+
+    @classmethod
+    def start_soon[**P](
+        cls,
+        callback: Callable[P, Any],
+        *args: P.args,
+        **kwargs: P.kwargs,
+    ) -> Callable[[], None]:
+        return cls.call_later(0, callback, *args, **kwargs)
+
+
 class ReachLimit(Exception):  # noqa: N818
     limit: int = 6
 
@@ -249,7 +191,7 @@ class ReachLimit(Exception):  # noqa: N818
 def _send_message():  # noqa: ANN202
     call_cnt: dict[int, int] = {}
 
-    def clean_cnt(key: int) -> None:  # pragma: no cover
+    async def clean(key: int) -> None:  # pragma: no cover
         if key in call_cnt:
             del call_cnt[key]
 
@@ -261,12 +203,12 @@ def _send_message():  # noqa: ANN202
         key = id(session)
         if key not in call_cnt:
             call_cnt[key] = 1
-            asyncio.get_event_loop().call_later(60, clean_cnt, key)
-        elif call_cnt[key] >= ReachLimit.limit or call_cnt[key] < 0:
+            GlobalTaskGroup.call_later(60, clean, key)
+        elif 0 <= call_cnt[key] < ReachLimit.limit:
+            call_cnt[key] += 1
+        else:
             call_cnt[key] = -1
             raise ReachLimit("消息发送触发次数限制")
-        else:
-            call_cnt[key] += 1
 
         msg = await as_unimsg(message)
         return await msg.send(target)
@@ -279,7 +221,6 @@ send_message = _send_message()
 
 class _Sudo:
     def __init__(self) -> None:
-        from ..config import config
         from ..context import Context
 
         self.__config = config
@@ -313,14 +254,20 @@ class _Sudo:
         )()
 
 
-def export_superuser() -> dict[str, Any]:
-    return {"sudo": _Sudo()}
+def export_superuser() -> Generator[tuple[str, Any], Any, None]:
+    yield from {"sudo": _Sudo()}.items()
+
+
+_msg_cls_cache: dict[str, tuple[type[Message], type[MessageSegment]]] = {}
 
 
-@functools.cache
 def _get_msg_cls(adapter: Adapter) -> tuple[type[Message], type[MessageSegment]]:
-    msg = UniMessage.text("text").export_sync(adapter=adapter.get_name())
-    return type(msg), msg.get_segment_class()
+    adapter_name = adapter.get_name()
+    if adapter_name in _msg_cls_cache:
+        return _msg_cls_cache[adapter_name]
+
+    msg = UniMessage.text("text").export_sync(adapter=adapter_name)
+    return _msg_cls_cache.setdefault(adapter_name, (type(msg), msg.get_segment_class()))
 
 
 @nonebot.get_driver().on_startup
@@ -331,6 +278,6 @@ async def _on_driver_startup() -> None:
         message_alia(*_get_msg_cls(a))
 
 
-def export_message(adapter: Adapter) -> dict[str, Any]:
+def export_message(adapter: Adapter) -> Generator[tuple[str, Any], Any, None]:
     m, ms = _get_msg_cls(adapter)
-    return {"Message": m, "MessageSegment": ms}
+    yield from {"Message": m, "MessageSegment": ms}.items()
