@@ -15,18 +15,19 @@ def _target(event: Event, target: Match[At]) -> str:
     return target.result.target if target.available else event.get_user_id()
 
 
-async def _context(target: Annotated[str, Depends(_target)]) -> Context | None:
+async def _context(target: Annotated[str, Depends(_target)]) -> Context:
     try:
         return Context.get_context(target)
     except Exception as err:
-        await matcher.finish(f"获取 Context 失败: {err}")
+        await matcher.send(f"获取 Context 失败: {err}")
+        matcher.skip()
 
 
 @matcher.handle()
 async def handle_terminate(
     target: Annotated[str, Depends(_target)],
-    context: Annotated[Context | None, Depends(_context)],
+    context: Annotated[Context, Depends(_context)],
 ) -> NoReturn:
-    if context is not None and context.cancel():
+    if context.cancel():
         await UniMessage("中止").at(target).text("的执行任务").send()
     await matcher.finish()
