@@ -8,11 +8,9 @@ from nonebot.adapters.onebot.v11.event import Reply, Sender
 from nonebot.exception import FinishedException
 from nonebug import App
 
-from tests.conftest import exe_code_group, superuser
-from tests.fake import (
-    ensure_context,
-    fake_img_bytes,
-    fake_user_id,
+from .conftest import exe_code_group, superuser
+from .fake.common import ensure_context, fake_img_bytes, fake_user_id
+from .fake.onebot11 import (
     fake_v11_bot,
     fake_v11_event_session,
     fake_v11_group_message_event,
@@ -54,9 +52,9 @@ async def test_getraw(app: App) -> None:
     context = Context.get_context(session).ctx
     gem = context.get("gem")
     assert gem is not None, "Context variable `gem` not set"
-    assert (
-        gem == reply_msg
-    ), f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
+    assert gem == reply_msg, (
+        f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
+    )
 
     gurl = context.get("gurl")
     assert gurl is None, "Got unexpected variable `gurl`"
@@ -97,9 +95,9 @@ async def test_getmid(app: App) -> None:
     context = Context.get_context(session).ctx
     gem = context.get("gem")
     assert gem is not None, "Context variable `gem` not set"
-    assert (
-        gem == reply_msg
-    ), f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
+    assert gem == reply_msg, (
+        f"Context variable `gem` error: expect `{reply_msg}`, got `{gem}`"
+    )
 
     gurl = context.get("gurl")
     assert gurl is None, "Got unexpected variable `gurl`"
@@ -275,10 +273,14 @@ async def test_terminate(app: App) -> None:
             user_id=superuser,
             message=Message("terminate"),
         )
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, "")
         ctx.receive_event(bot, event)
         ctx.should_pass_permission(matcher)
         ctx.should_finished(matcher)
 
+    async with app.test_matcher(matcher) as ctx:
+        bot = fake_v11_bot(ctx)
         target_id = fake_user_id()
         event = fake_v11_group_message_event(
             group_id=exe_code_group,
@@ -289,9 +291,9 @@ async def test_terminate(app: App) -> None:
         ctx.should_pass_permission(matcher)
         ctx.should_call_send(
             event,
-            f"获取 Context 失败: session ('{target_id}', '{bot.type}') not initialized",
+            "获取 Context 失败: "
+            f"SessionNotInitialized: None, key=('{target_id}', '{bot.type}')",
         )
-        ctx.should_finished(matcher)
 
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
