@@ -1,23 +1,14 @@
 # ruff: noqa: N806, N814
 
-import asyncio
 
 import pytest
 from nonebot.adapters.onebot.v11 import ActionFailed, Message, MessageSegment
-from nonebot.adapters.qq.models import MessageArk, MessageArkKv
+from nonebot.adapters.onebot.v11.event import Reply, Sender
 from nonebug import App
-from pytest_mock import MockerFixture
 
-from tests.conftest import exe_code_group, exe_code_qbot_id
-from tests.fake import (
-    ensure_context,
-    fake_group_id,
-    fake_qq_bot,
-    fake_qq_c2c_message_create_event,
-    fake_v11_bot,
-    fake_v11_event_session,
-    fake_v11_private_message_event,
-)
+from .conftest import exe_code_group
+from .fake.common import ensure_context, fake_group_id
+from .fake.onebot11 import fake_v11_bot, fake_v11_event_session
 
 code_test_ob11_img_summary = """\
 await api.img_summary("test")
@@ -27,6 +18,7 @@ await api.img_summary("test")
 @pytest.mark.asyncio
 async def test_ob11_img_summary(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMissing
 
     url = "http://localhost:8080/image.png"
     expected = Message(MessageSegment.image(url))
@@ -35,7 +27,7 @@ async def test_ob11_img_summary(app: App) -> None:
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
         event, session = fake_v11_event_session(bot, group_id=exe_code_group)
-        with ensure_context(bot, event), pytest.raises(ValueError, match="无效 url"):
+        with ensure_context(bot, event), pytest.raises(ParamMissing, match="无效 url"):
             await Context.execute(bot, event, code_test_ob11_img_summary)
         Context.get_context(session).set_value("gurl", url)
         ctx.should_call_send(event, expected)
@@ -244,6 +236,7 @@ await api.set_card("test_card")
 @pytest.mark.asyncio
 async def test_ob11_set_card(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMissing
 
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
@@ -260,131 +253,22 @@ async def test_ob11_set_card(app: App) -> None:
             await Context.execute(bot, event, code_test_ob11_set_card)
 
         event, _ = fake_v11_event_session(bot)
-        with ensure_context(bot, event), pytest.raises(ValueError, match="未指定群号"):
+        with (
+            ensure_context(bot, event),
+            pytest.raises(ParamMissing, match="未指定群号"),
+        ):
             await Context.execute(bot, event, code_test_ob11_set_card)
 
 
-code_test_ob11_send_ark = """\
-await api.ark_24("title", "desc", "prompt", "img", "link")
-"""
-expected_ark_24 = MessageArk(
-    template_id=24,
-    kv=[
-        MessageArkKv(key="#TITLE#", value="title"),
-        MessageArkKv(key="#METADESC#", value="desc"),
-        MessageArkKv(key="#PROMPT#", value="prompt"),
-        MessageArkKv(key="#IMG#", value="img"),
-        MessageArkKv(key="#LINK#", value="link"),
-    ],
-)
-
-
-@pytest.mark.asyncio
-async def test_ob11_send_ark(app: App, mocker: MockerFixture) -> None:
-    import uuid
-
-    from nonebot.adapters.qq import MessageSegment as QQMS
-    from nonebot.message import handle_event
-
-    from nonebot_plugin_exe_code.context import Context
-
-    mocker.patch("os.urandom", return_value=b"0" * 16)
-    key = f"$ARK-{uuid.uuid4()}$"
-    card = "JSON_DATA"
-
-    async with app.test_api() as ctx:
-        botV11 = fake_v11_bot(ctx, self_id="test-v11")
-        botQQ = fake_qq_bot(ctx, self_id="test-qq")
-
-        event_code, _ = fake_v11_event_session(botV11)
-        event_qq = fake_qq_c2c_message_create_event(content=key)
-        event_v11 = fake_v11_private_message_event(
-            user_id=exe_code_qbot_id,
-            message=Message(MessageSegment.json(card)),
-        )
-        ctx.should_call_api(
-            "send_msg",
-            {
-                "message_type": "private",
-                "user_id": exe_code_qbot_id,
-                "message": Message(key),
-            },
-            {"message_id": 1},
-        )
-        ctx.should_call_send(event_qq, QQMS.ark(expected_ark_24), bot=botQQ)
-        ctx.should_call_send(event_code, Message(MessageSegment.json(card)))
-
-        async def _test1() -> None:
-            with ensure_context(botV11, event_code):
-                await Context.execute(botV11, event_code, code_test_ob11_send_ark)
-
-        async def _test2() -> None:
-            await asyncio.sleep(0.01)
-            await handle_event(botQQ, event_qq)
-
-        async def _test3() -> None:
-            await asyncio.sleep(0.02)
-            await handle_event(botV11, event_v11)
-
-        await asyncio.gather(_test1(), _test2(), _test3())
-
-
-@pytest.mark.asyncio
-async def test_ob11_send_ark_fail(app: App, mocker: MockerFixture) -> None:
-    import uuid
-
-    from nonebot.adapters.qq import MessageSegment as QQMS
-    from nonebot.message import handle_event
-
-    from nonebot_plugin_exe_code.context import Context
-
-    mocker.patch("os.urandom", return_value=b"0" * 16)
-    key = f"$ARK-{uuid.uuid4()}$"
-
-    async with app.test_api() as ctx:
-        botV11 = fake_v11_bot(ctx, self_id="test-v11")
-        botQQ = fake_qq_bot(ctx, self_id="test-qq")
-
-        event_code, _ = fake_v11_event_session(botV11)
-        event_qq = fake_qq_c2c_message_create_event(content=key)
-        ctx.should_call_api(
-            "send_msg",
-            {
-                "message_type": "private",
-                "user_id": exe_code_qbot_id,
-                "message": Message(key),
-            },
-            {"message_id": 1},
-        )
-        ctx.should_call_send(
-            event_qq,
-            QQMS.ark(expected_ark_24),
-            bot=botQQ,
-            exception=RuntimeError("test"),
-        )
-
-        async def _test1() -> None:
-            with (
-                ensure_context(botV11, event_code),
-                pytest.raises(RuntimeError, match="test"),
-            ):
-                await Context.execute(botV11, event_code, code_test_ob11_send_ark)
-
-        async def _test2() -> None:
-            await asyncio.sleep(0.01)
-            await handle_event(botQQ, event_qq)
-
-        await asyncio.gather(_test1(), _test2())
-
-
 code_test_ob11_set_mute = """\
-await api.set_mute(114514, qid)
+await api.set_mute(114514, uid)
 """
 
 
 @pytest.mark.asyncio
 async def test_ob11_set_mute(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMissing
 
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
@@ -401,7 +285,10 @@ async def test_ob11_set_mute(app: App) -> None:
             await Context.execute(bot, event, code_test_ob11_set_mute)
 
         event, _ = fake_v11_event_session(bot)
-        with ensure_context(bot, event), pytest.raises(ValueError, match="未指定群号"):
+        with (
+            ensure_context(bot, event),
+            pytest.raises(ParamMissing, match="未指定群号"),
+        ):
             await Context.execute(bot, event, code_test_ob11_set_mute)
 
 
@@ -434,6 +321,7 @@ await api.send_private_file("file", "name", "string")
 @pytest.mark.asyncio
 async def test_ob11_send_private_file(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMismatch
 
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
@@ -442,7 +330,7 @@ async def test_ob11_send_private_file(app: App) -> None:
             "upload_private_file",
             {"user_id": event.user_id, "file": "file", "name": "name"},
         )
-        with ensure_context(bot, event), pytest.raises(ValueError, match="不是数字"):
+        with ensure_context(bot, event), pytest.raises(ParamMismatch, match="不是数字"):
             await Context.execute(bot, event, code_test_ob11_send_private_file)
 
 
@@ -455,6 +343,7 @@ await api.send_group_file("file", "name", "string")
 @pytest.mark.asyncio
 async def test_ob11_send_group_file(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMismatch, ParamMissing
 
     async with app.test_api() as ctx:
         bot = fake_v11_bot(ctx)
@@ -463,11 +352,14 @@ async def test_ob11_send_group_file(app: App) -> None:
             "upload_group_file",
             {"group_id": event.group_id, "file": "file", "name": "name"},
         )
-        with ensure_context(bot, event), pytest.raises(ValueError, match="不是数字"):
+        with ensure_context(bot, event), pytest.raises(ParamMismatch, match="不是数字"):
             await Context.execute(bot, event, code_test_ob11_send_group_file)
 
         event, _ = fake_v11_event_session(bot)
-        with ensure_context(bot, event), pytest.raises(ValueError, match="未指定群号"):
+        with (
+            ensure_context(bot, event),
+            pytest.raises(ParamMissing, match="未指定群号"),
+        ):
             await Context.execute(bot, event, code_test_ob11_send_group_file)
 
 
@@ -546,51 +438,6 @@ async def test_ob11_mid(app: App) -> None:
             await Context.execute(bot, event, "print(api.mid)")
 
 
-code_test_ob11_set_reaction = """\
-await api.set_reaction(123, api.mid, 456)
-"""
-
-
-@pytest.mark.asyncio
-async def test_ob11_set_reaction(app: App) -> None:
-    from nonebot_plugin_exe_code.context import Context
-
-    async with app.test_api() as ctx:
-        bot = fake_v11_bot(ctx)
-        event, _ = fake_v11_event_session(bot)
-
-        ctx.should_call_api(
-            "set_msg_emoji_like",
-            {"message_id": 1, "emoji_id": 123},
-            result=None,
-        )
-        ctx.should_call_api(
-            "set_msg_emoji_like",
-            {"message_id": 1, "emoji_id": 123},
-            exception=ActionFailed(),
-        )
-        ctx.should_call_api(
-            "set_group_reaction",
-            {"group_id": 456, "message_id": 1, "code": "123"},
-            result=None,
-        )
-        ctx.should_call_api(
-            "set_msg_emoji_like",
-            {"message_id": 1, "emoji_id": 123},
-            exception=ActionFailed(),
-        )
-        ctx.should_call_api(
-            "set_group_reaction",
-            {"group_id": 456, "message_id": 1, "code": "123"},
-            exception=ActionFailed(),
-        )
-        with ensure_context(bot, event):
-            await Context.execute(bot, event, code_test_ob11_set_reaction)
-            await Context.execute(bot, event, code_test_ob11_set_reaction)
-            with pytest.raises(RuntimeError, match="发送消息回应失败"):
-                await Context.execute(bot, event, code_test_ob11_set_reaction)
-
-
 @pytest.mark.asyncio
 async def test_ob11_send_fwd(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
@@ -636,3 +483,162 @@ async def test_ob11_send_fwd(app: App) -> None:
                 event,
                 'await api.send_fwd([UserStr("123") @ "1" @ "test", "2"])',
             )
+
+
+code_test_ob11_get_platform = """\
+print(await api.get_platform())
+"""
+
+
+@pytest.mark.asyncio
+async def test_ob11_get_platform(app: App) -> None:
+    from nonebot_plugin_exe_code.context import Context
+
+    expected = Message(MessageSegment.text("[OneBot V11] app_name app_version"))
+
+    async with app.test_api() as ctx:
+        bot = fake_v11_bot(ctx)
+        event, _ = fake_v11_event_session(bot)
+        ctx.should_call_api(
+            "get_version_info",
+            {},
+            {"app_name": "app_name", "app_version": "app_version"},
+        )
+        ctx.should_call_send(event, expected)
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, code_test_ob11_get_platform)
+
+
+@pytest.mark.asyncio
+async def test_ob11_set_reaction(app: App) -> None:
+    from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import APICallFailed
+
+    code_test_ob11_set_reaction_1 = "await api.set_reaction(123, api.mid, 456)"
+    code_test_ob11_set_reaction_2 = "await api.set_reaction(123, api.mid)"
+    code_test_ob11_set_reaction_3 = "await api.set_reaction(123)"
+
+    async with app.test_api() as ctx:
+        bot = fake_v11_bot(ctx)
+        event, _ = fake_v11_event_session(bot)
+
+        # 1. NapCat
+        ctx.should_call_api(
+            "get_version_info",
+            {},
+            {"app_name": "NapCat", "app_version": "app_version"},
+        )
+        ctx.should_call_api(
+            "set_msg_emoji_like",
+            {"message_id": 1, "emoji_id": 123},
+            result=None,
+        )
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, code_test_ob11_set_reaction_1)
+
+        # 2. LLOneBot
+        ctx.should_call_api(
+            "get_version_info",
+            {},
+            {"app_name": "LLOneBot", "app_version": "app_version"},
+        )
+        ctx.should_call_api(
+            "set_msg_emoji_like",
+            {"message_id": 1, "emoji_id": 123},
+            result=None,
+        )
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, code_test_ob11_set_reaction_1)
+
+        # 3. Lagrange with gid
+        ctx.should_call_api(
+            "get_version_info",
+            {},
+            {"app_name": "Lagrange", "app_version": "app_version"},
+        )
+        ctx.should_call_api(
+            "set_group_reaction",
+            {"group_id": 456, "message_id": 1, "code": "123"},
+            result=None,
+        )
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, code_test_ob11_set_reaction_1)
+
+        # 3. Lagrange without gid
+        ctx.should_call_api(
+            "get_version_info",
+            {},
+            {"app_name": "Lagrange", "app_version": "app_version"},
+        )
+        with ensure_context(bot, event), pytest.raises(TypeError, match="Lagrange"):
+            await Context.execute(bot, event, code_test_ob11_set_reaction_2)
+
+        # 4. Unkown platform
+        ctx.should_call_api(
+            "get_version_info",
+            {},
+            {"app_name": "Unkown Platform", "app_version": "app_version"},
+        )
+        with (
+            ensure_context(bot, event),
+            pytest.raises(APICallFailed, match="unkown platform"),
+        ):
+            await Context.execute(bot, event, code_test_ob11_set_reaction_1)
+
+        # 5. without mid
+        event.reply = Reply(
+            time=1000000,
+            message_type="test",
+            message_id=111,
+            real_id=1,
+            sender=Sender(
+                card="",
+                nickname="test",
+                role="member",
+            ),
+            message=Message(),
+        )
+        ctx.should_call_api(
+            "get_version_info",
+            {},
+            {"app_name": "NapCat", "app_version": "app_version"},
+        )
+        ctx.should_call_api(
+            "set_msg_emoji_like",
+            {"message_id": 111, "emoji_id": 123},
+            result=None,
+        )
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, code_test_ob11_set_reaction_3)
+
+
+@pytest.mark.asyncio
+async def test_ob11_group_poke(app: App) -> None:
+    from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMissing
+
+    async with app.test_api() as ctx:
+        bot = fake_v11_bot(ctx)
+
+        event, _ = fake_v11_event_session(bot, group_id=fake_group_id())
+        ctx.should_call_api(
+            "group_poke",
+            {"group_id": event.group_id, "user_id": event.user_id},
+        )
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, "await api.group_poke(uid)")
+
+        event, _ = fake_v11_event_session(bot)
+        with (
+            ensure_context(bot, event),
+            pytest.raises(ParamMissing, match="未指定群号"),
+        ):
+            await Context.execute(bot, event, "await api.group_poke(uid)")
+
+        event, _ = fake_v11_event_session(bot, group_id=fake_group_id())
+        ctx.should_call_api(
+            "group_poke",
+            {"group_id": event.group_id, "user_id": event.user_id},
+        )
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, "await api.group_poke(uid, gid)")
