@@ -2,15 +2,14 @@ import pytest
 from nonebot.adapters.satori import Message
 from nonebug import App
 
-from tests.conftest import exe_code_group, exe_code_user, superuser
-from tests.fake import (
-    ensure_context,
-    fake_group_id,
+from .conftest import exe_code_group, exe_code_user, superuser
+from .fake.common import ensure_context, fake_group_id, fake_user_id
+from .fake.satori import (
     fake_satori_bot,
     fake_satori_event_session,
+    fake_satori_login,
     fake_satori_private_message_created_event,
     fake_satori_public_message_created_event,
-    fake_user_id,
 )
 
 
@@ -22,7 +21,7 @@ async def test_satori_private(app: App) -> None:
         bot = fake_satori_bot(ctx)
         event = fake_satori_private_message_created_event(
             user_id=str(superuser),
-            content="code print(qid, gid)",
+            content="code print(uid, gid)",
         )
         expected = Message(f"{superuser} private:{superuser}")
         ctx.receive_event(bot, event)
@@ -41,7 +40,7 @@ async def test_satori_public(app: App) -> None:
         event = fake_satori_public_message_created_event(
             user_id=user_id,
             channel_id=str(exe_code_group),
-            content="code print(qid, gid)",
+            content="code print(uid, gid)",
         )
         expected = Message(f"{user_id} {exe_code_group}")
         ctx.receive_event(bot, event)
@@ -53,7 +52,7 @@ async def test_satori_public(app: App) -> None:
         event = fake_satori_public_message_created_event(
             user_id=str(exe_code_user),
             channel_id=channel_id,
-            content="code print(qid, gid)",
+            content="code print(uid, gid)",
         )
         expected = Message(f"{exe_code_user} {channel_id}")
         ctx.receive_event(bot, event)
@@ -70,6 +69,7 @@ await api.set_mute(7685)
 @pytest.mark.asyncio
 async def test_satori_set_mute(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMissing
 
     async with app.test_api() as ctx:
         bot = fake_satori_bot(ctx)
@@ -88,7 +88,7 @@ async def test_satori_set_mute(app: App) -> None:
         event, _ = fake_satori_event_session(bot)
         with (
             ensure_context(bot, event),
-            pytest.raises(ValueError, match="未指定群组ID"),
+            pytest.raises(ParamMissing, match="未指定群组ID"),
         ):
             await Context.execute(bot, event, code_test_satori_set_mute)
 
@@ -113,11 +113,21 @@ await api.set_reaction(123, api.mid)
 @pytest.mark.asyncio
 async def test_satori_set_reaction(app: App) -> None:
     from nonebot_plugin_exe_code.context import Context
+    from nonebot_plugin_exe_code.exception import ParamMissing
 
     async with app.test_api() as ctx:
         bot = fake_satori_bot(ctx)
 
         event, _ = fake_satori_event_session(bot, channel_id=str(exe_code_group))
+        ctx.should_call_api(
+            "reaction_create",
+            {
+                "channel_id": str(exe_code_group),
+                "message_id": "10000",
+                "emoji": "123",
+            },
+            result=None,
+        )
         ctx.should_call_api(
             "reaction_create",
             {
@@ -133,6 +143,26 @@ async def test_satori_set_reaction(app: App) -> None:
         event, _ = fake_satori_event_session(bot)
         with (
             ensure_context(bot, event),
-            pytest.raises(ValueError, match="未指定群组ID"),
+            pytest.raises(ParamMissing, match="未指定群组ID"),
         ):
             await Context.execute(bot, event, code_test_satori_set_reaction)
+
+
+code_test_satori_get_platform = """\
+print(await api.get_platform())
+"""
+
+
+@pytest.mark.asyncio
+async def test_satori_get_platform(app: App) -> None:
+    from nonebot_plugin_exe_code.context import Context
+
+    expected = Message("[Satori] platform")
+
+    async with app.test_api() as ctx:
+        bot = fake_satori_bot(ctx)
+        event, _ = fake_satori_event_session(bot)
+        ctx.should_call_api("login_get", {}, fake_satori_login())
+        ctx.should_call_send(event, expected)
+        with ensure_context(bot, event):
+            await Context.execute(bot, event, code_test_satori_get_platform)
